Personal Scrapping Library
==========================

.. image:: https://badge.fury.io/py/dli-scrapping-lib.svg
    :target: https://badge.fury.io/py/dli-scrapping-lib

Various web scrapping functions I have written over the years.

To install 

.. code-block:: python

  pip install dli-scrapping-lib
